package org.kantega.jexmec;

/*
 * Copyright 2010 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Abstract class representing a component providing extended functionality to an application.
 * This class only contains generic meta-information. Application specific methods will be found
 * in subclasses.
 *
 */
public abstract class Plugin {

    /**
     * The globally unique plugin id.
     */
    private final String pluginUid;

    /**
     * This constructor creates a plugin with a given plugin uid.
     * @param pluginUid the pluginUid of this plugin
     */
    protected Plugin(final String pluginUid) {
        this.pluginUid = pluginUid;
    }

    /**
     * Return a globally unique string identifying this plugin.
     * Will typically be in the form of a revese internet domain name followed by organization specific
     * identification, such as <code>com.example.app.plugins.myplugin</code>
     * @return the globally unique plugin id
     */
    public final String getPluginUid() {
        return pluginUid;
    }

}
