package org.kantega.jexmec;

/*
 * Copyright 2010 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.util.List;

/**
 * Keeps track of plugins currently installed in the application. Application and plugin
 * code should call the getPlugins() method when they need to iterate over installed plugins.
 */
public interface PluginManager<P extends Plugin> {
    /**
     * Return a list of the {@link Plugin}s currently installed in this PluginManager
     * @return  the list of plugins
     */
    List<P> getPlugins();

    /**
     * Register a PluginManagerListener for event notification.
     * @param listener the listener to add
     */
    void addPluginManagerListener(PluginManagerListener<P> listener);

    /**
     * Unregister a PluginManagerListener for event notification.
     * @param listener the listener to remove
     */
    void removePluginManagerListener(PluginManagerListener<P> listener);

    /**
     * Return the ClassLoader from which the given plugin was loaded.
     * @param plugin the plugin for which to return the loading plugin.
     * @return the ClassLoader from which the given plugin was loaded.
     */
    ClassLoader getClassLoader(P plugin);
}
