package org.kantega.jexmec;

/*
 * Copyright 2010 Kantega AS
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Listener class for PluginManager events.
 */
public abstract class PluginManagerListener<P extends Plugin> {
    /**
     * Fires when pluginManager.start() has finished its work and all
     * initial plugins have been loaded.
     */
    public void pluginManagerStarted() {}

    /**
     * Fired when a PluginLoader has added a new ClassLoader.
     *
     * @param classLoader the classLoader being added
     */
    public void classLoaderAdded(ClassLoader classLoader) {}

    /**
     * Fired when a PluginLoader has removed a new ClassLoader.
     *
     * @param classLoader the classLoader being removed
     */
    public void classLoaderRemoved(ClassLoader classLoader) {}
}


