package org.kantega.jexmec.simple;

import org.kantega.jexmec.ServiceKey;
import org.kantega.jexmec.ServiceLocator;

import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Method;
import java.lang.reflect.Proxy;

/**
 *
 */
public class ServicesProxyFactory {

    private ServicesProxyFactory() {}

    public static <S> S create(final Class<S> servicesClass, ServiceLocator serviceLocator) {
        return servicesClass.cast(Proxy.newProxyInstance(ServicesProxyFactory.class.getClassLoader(),
                new Class[]{servicesClass},
                new ServiceLookupInvocationHandler(serviceLocator)));
    }

    private static class ServiceLookupInvocationHandler implements InvocationHandler {
        private ServiceLocator serviceLocator;

        public ServiceLookupInvocationHandler(ServiceLocator serviceLocator) {
            this.serviceLocator = serviceLocator;
        }

        public Object invoke(Object o, Method method, Object[] objects) throws Throwable {
            if (objects == null || objects.length == 0) {
                return serviceLocator.lookupService(ServiceKey.by(method.getReturnType()));
            } else {
                return serviceLocator.lookupService(ServiceKey.by(method.getReturnType(), ((Enum) objects[0]).name()));
            }
        }
    }
}
